"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _integer = _interopRequireDefault(require("../integer"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const dateInSeconds = _date => {
  return Math.floor(new Date(_date).valueOf() / 1000);
};
/**
 * For convenience of compatibility with `fake.day()` defaults, use 1001-01-01 00:00:00 and
 * 9999-01-01 00:00:00 as the default `from` and `to`, respectively. See comment in `fake.day()` for
 * context on why we use these defaults.
 */


const DEFAULT_FROM = new Date(-30578688000000);
const DEFAULT_TO = new Date(253370764800000);
/**
 * Returns a randomly-selected `Date`, optionally between `from` and `to`.
 */

const createDateGenerator = chance => function () {
  let from = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : DEFAULT_FROM;
  let to = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : DEFAULT_TO;
  const integer = (0, _integer.default)(chance);

  if (typeof from === 'string') {
    from = new Date(from);
  }

  if (Number.isNaN(from.valueOf())) {
    throw new RangeError('`from` is not a valid date');
  }

  if (typeof to === 'string') {
    to = new Date(to);
  }

  if (Number.isNaN(to.valueOf())) {
    throw new RangeError('`to` is not a valid date');
  }

  return new Date(integer(dateInSeconds(from), dateInSeconds(to)) * 1000);
};

var _default = createDateGenerator;
exports.default = _default;
//# sourceMappingURL=index.js.map