"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _utils = require("../../utils");

/**
 * unique accepts a generator function and a number of items to generate and returns an array of
 * unique values. It throws a RangeError when it is unable to generate an array of unique values.
 *
 * By default it compares each new generated value against all other generated values using a
 * `sameValueZero` (`Object.is`) comparsion. You can customize this behavior by passing your own
 * comparator via `options.isEqual`.
 */
const createUniqueGenerator = _chance => function (generator) {
  let {
    isEqual = Object.is
  } = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

  const isUniqueValue = (items, val) => !items.some(item => isEqual(item, val));

  const results = [];
  return function () {
    const maxRetries = results.length === 0 ? 50 : 50 * results.length; // eslint-disable-next-line @typescript-eslint/no-unused-vars

    for (const r of (0, _utils.range)(0, maxRetries)) {
      const value = generator(...arguments);

      if (isUniqueValue(results, value)) {
        results.push(value);
        return value;
      }
    }

    throw new RangeError(`Failed to generate a unique value; the provided generator may not be capable of creating a unique value, or your arguments may be too specific.`);
  };
};

var _default = createUniqueGenerator;
exports.default = _default;
//# sourceMappingURL=index.js.map