/// <reference types="chance" />
export interface CreateFakeEggsOptions {
    /**
     * seed is an optional value that can be passed to the fake data generator to generate
     * repeatably random data (it will generate the same data for the same sequence of calls).
     * When `process.env.FAKE_EGGS_SEED` is set to a non-empty value and `seed` is not explicitly
     * passed, `process.env.FAKE_EGGS_SEED` will be used.
     *
     * This can be used, for example, to make it easier to reproduce flaky tests locally:
     *
     * ```
     * // local_modules/fake_eggs/index.ts
     * if (process.env.FAKE_DATA_SEED != null) {
     *   console.log(`Using fake data seed for tests: ${process.env.FAKE_DATA_SEED}`);
     * }
     * export default createFakeEggs({seed: process.env.FAKE_DATA_SEED});
     *
     * // When running tests:
     * FAKE_DATA_SEED="$(date)" yarn run test
     * FAKE_DATA_SEED="${BUILDKITE_BUILD_ID}" yarn run test
     * FAKE_DATA_SEED="${TRAVIS_BUILD_ID}" yarn run test
     * ```
     */
    seed?: string;
}
export declare const createFakeEggs: ({ seed, }?: CreateFakeEggsOptions) => {
    /**
     * Chance itself
     */
    chance: Chance.Chance;
    maybe: <T>(alwaysValue: () => T) => T | null | undefined;
    nullable: <T_1>(alwaysValue: () => T_1) => T_1 | null;
    optional: <T_2>(alwaysValue: () => T_2) => T_2 | undefined;
    address: () => string;
    array: <T_3>(lengthLowerInclusive: number, lengthUpperExclusive: number, generator: () => T_3) => T_3[];
    boolean: () => boolean;
    customer: {
        firstName: () => string;
        lastName: () => string;
        phoneNumber: () => string;
        fullName: (firstName?: string | undefined, lastName?: string | undefined) => string;
        email: ({ domain, username }?: {
            domain?: string | undefined;
            username?: string | undefined;
        }) => string;
    };
    date: (from?: string | Date, to?: string | Date) => Date;
    day: (from?: string | Date, to?: string | Date) => string;
    digit: () => number;
    email: ({ domain, username }?: {
        domain?: string | undefined;
        username?: string | undefined;
    }) => string;
    employee: {
        firstName: () => string;
        lastName: () => string;
        phoneNumber: () => string;
        fullName: (firstName?: string | undefined, lastName?: string | undefined) => string;
        email: (options?: {
            firstName?: string | undefined;
            lastName?: string | undefined;
        }) => string;
    };
    firstName: () => string;
    foodhub: {
        slug: () => string;
    };
    fullName: (firstName?: string | undefined, lastName?: string | undefined) => string;
    integer: (lowerInclusive?: number, upperExclusive?: number) => number;
    lastName: () => string;
    location: {
        address: () => string;
        state: () => string;
        zip: (opts?: Chance.Options | undefined) => string;
    };
    number: (lowerInclusive?: number, upperExclusive?: number, fixed?: number) => number;
    objectId: ({ counter, from, machineId, processId, timestamp, to, }?: {
        counter?: number | undefined;
        from?: string | Date | undefined;
        machineId?: number | undefined;
        processId?: number | undefined;
        timestamp?: string | number | Date | undefined;
        to?: string | Date | undefined;
    }) => string;
    phoneNumber: () => string;
    producer: {
        name: () => string;
        slug: (slug?: string | undefined) => string;
    };
    product: {
        count: () => number;
        name: () => string;
        storageType: () => string;
        unit: () => string;
    };
    sample: <T_4>(array: T_4[]) => T_4;
    sentence: () => string;
    string: (length?: number, charset?: string) => string;
    tzid: (tzids?: string[]) => string;
    unique: <T_5, A extends unknown[]>(generator: (...args: A) => T_5, { isEqual, }?: {
        isEqual?: ((a: T_5, b: T_5) => boolean) | undefined;
    }) => (...args: A) => T_5;
    uri: (domain?: string) => string;
    word: (length?: number | undefined, charset?: string) => string;
    zip: (opts?: Chance.Options | undefined) => string;
};
declare const _default: {
    /**
     * Chance itself
     */
    chance: Chance.Chance;
    maybe: <T>(alwaysValue: () => T) => T | null | undefined;
    nullable: <T_1>(alwaysValue: () => T_1) => T_1 | null;
    optional: <T_2>(alwaysValue: () => T_2) => T_2 | undefined;
    address: () => string;
    array: <T_3>(lengthLowerInclusive: number, lengthUpperExclusive: number, generator: () => T_3) => T_3[];
    boolean: () => boolean;
    customer: {
        firstName: () => string;
        lastName: () => string;
        phoneNumber: () => string;
        fullName: (firstName?: string | undefined, lastName?: string | undefined) => string;
        email: ({ domain, username }?: {
            domain?: string | undefined;
            username?: string | undefined;
        }) => string;
    };
    date: (from?: string | Date, to?: string | Date) => Date;
    day: (from?: string | Date, to?: string | Date) => string;
    digit: () => number;
    email: ({ domain, username }?: {
        domain?: string | undefined;
        username?: string | undefined;
    }) => string;
    employee: {
        firstName: () => string;
        lastName: () => string;
        phoneNumber: () => string;
        fullName: (firstName?: string | undefined, lastName?: string | undefined) => string;
        email: (options?: {
            firstName?: string | undefined;
            lastName?: string | undefined;
        }) => string;
    };
    firstName: () => string;
    foodhub: {
        slug: () => string;
    };
    fullName: (firstName?: string | undefined, lastName?: string | undefined) => string;
    integer: (lowerInclusive?: number, upperExclusive?: number) => number;
    lastName: () => string;
    location: {
        address: () => string;
        state: () => string;
        zip: (opts?: Chance.Options | undefined) => string;
    };
    number: (lowerInclusive?: number, upperExclusive?: number, fixed?: number) => number;
    objectId: ({ counter, from, machineId, processId, timestamp, to, }?: {
        counter?: number | undefined;
        from?: string | Date | undefined;
        machineId?: number | undefined;
        processId?: number | undefined;
        timestamp?: string | number | Date | undefined;
        to?: string | Date | undefined;
    }) => string;
    phoneNumber: () => string;
    producer: {
        name: () => string;
        slug: (slug?: string | undefined) => string;
    };
    product: {
        count: () => number;
        name: () => string;
        storageType: () => string;
        unit: () => string;
    };
    sample: <T_4>(array: T_4[]) => T_4;
    sentence: () => string;
    string: (length?: number, charset?: string) => string;
    tzid: (tzids?: string[]) => string;
    unique: <T_5, A extends unknown[]>(generator: (...args: A) => T_5, { isEqual, }?: {
        isEqual?: ((a: T_5, b: T_5) => boolean) | undefined;
    }) => (...args: A) => T_5;
    uri: (domain?: string) => string;
    word: (length?: number | undefined, charset?: string) => string;
    zip: (opts?: Chance.Options | undefined) => string;
};
export default _default;
//# sourceMappingURL=index.d.ts.map