"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.createFakeEggs = void 0;

var _chance = require("chance");

var _debug = _interopRequireDefault(require("debug"));

var _address = _interopRequireDefault(require("./generators/address"));

var _array = _interopRequireDefault(require("./generators/array"));

var _boolean = _interopRequireDefault(require("./generators/boolean"));

var _customer = _interopRequireDefault(require("./generators/customer"));

var _date = _interopRequireDefault(require("./generators/date"));

var _day = _interopRequireDefault(require("./generators/day"));

var _digit = _interopRequireDefault(require("./generators/digit"));

var _email = _interopRequireDefault(require("./generators/email"));

var _employee = _interopRequireDefault(require("./generators/employee"));

var _first_name = _interopRequireDefault(require("./generators/first_name"));

var _foodhub = _interopRequireDefault(require("./generators/foodhub"));

var _full_name = _interopRequireDefault(require("./generators/full_name"));

var _unique = _interopRequireDefault(require("./generators/unique"));

var _integer = _interopRequireDefault(require("./generators/integer"));

var _last_name = _interopRequireDefault(require("./generators/last_name"));

var _location = _interopRequireDefault(require("./generators/location"));

var _maybe = _interopRequireDefault(require("./combinators/maybe"));

var _nullable = _interopRequireDefault(require("./combinators/nullable"));

var _number = _interopRequireDefault(require("./generators/number"));

var _object_id = _interopRequireDefault(require("./generators/object_id"));

var _optional = _interopRequireDefault(require("./combinators/optional"));

var _phone_number = _interopRequireDefault(require("./generators/phone_number"));

var _producer = _interopRequireDefault(require("./generators/producer"));

var _product = _interopRequireDefault(require("./generators/product"));

var _sample = _interopRequireDefault(require("./generators/sample"));

var _sentence = _interopRequireDefault(require("./generators/sentence"));

var _string = _interopRequireDefault(require("./generators/string"));

var _tzid = _interopRequireDefault(require("./generators/tzid"));

var _uri = _interopRequireDefault(require("./generators/uri"));

var _word = _interopRequireDefault(require("./generators/word"));

var _zip = _interopRequireDefault(require("./generators/zip"));

var _utils = require("./utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const parentDebug = (0, _debug.default)(`@goodeggs/fake-eggs`);

const createFakeEggs = function () {
  let {
    seed = Math.floor(Math.random() * 10 ** 13).toString()
  } = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  const debug = parentDebug.extend(seed);
  const chance = new _chance.Chance(seed);
  debug(`Initialized fake-eggs`);
  return {
    /**
     * Chance itself
     */
    chance,

    /*
     * Combinators
     */
    maybe: (0, _maybe.default)(chance),
    nullable: (0, _nullable.default)(chance),
    optional: (0, _optional.default)(chance),

    /*
     * Generators
     */
    address: (0, _address.default)(chance),
    array: (0, _array.default)(chance),
    boolean: (0, _boolean.default)(chance),
    customer: (0, _customer.default)(chance),
    date: (0, _date.default)(chance),
    day: (0, _day.default)(chance),
    digit: (0, _digit.default)(chance),
    email: (0, _email.default)(chance),
    employee: (0, _employee.default)(chance),
    firstName: (0, _first_name.default)(chance),
    foodhub: (0, _foodhub.default)(chance),
    fullName: (0, _full_name.default)(chance),
    integer: (0, _integer.default)(chance),
    lastName: (0, _last_name.default)(chance),
    location: (0, _location.default)(chance),
    number: (0, _number.default)(chance),
    objectId: (0, _object_id.default)(chance),
    phoneNumber: (0, _phone_number.default)(chance),
    producer: (0, _producer.default)(chance),
    product: (0, _product.default)(chance),
    sample: (0, _sample.default)(chance),
    sentence: (0, _sentence.default)(chance),
    string: (0, _string.default)(chance),
    tzid: (0, _tzid.default)(chance),
    unique: (0, _unique.default)(chance),
    uri: (0, _uri.default)(chance),
    word: (0, _word.default)(chance),
    zip: (0, _zip.default)(chance)
  };
};

exports.createFakeEggs = createFakeEggs;

const getDefaultSeed = () => {
  var _global, _global$process;

  const env = (_global = global) === null || _global === void 0 ? void 0 : (_global$process = _global.process) === null || _global$process === void 0 ? void 0 : _global$process.env;

  if (env != null) {
    if ((0, _utils.isNonEmptyString)(env.FAKE_DATA_SEED)) {
      return env.FAKE_DATA_SEED;
    } else if ((0, _utils.isNonEmptyString)(env.TRAVIS_BUILD_ID)) {
      return env.TRAVIS_BUILD_ID;
    } else if ((0, _utils.isNonEmptyString)(env.BUILDKITE_BUILD_ID)) {
      return env.BUILDKITE_BUILD_ID;
    }
  }
};

var _default = createFakeEggs({
  seed: getDefaultSeed()
});

exports.default = _default;
//# sourceMappingURL=index.js.map